@@ -5,17 +5,17 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-pinpointemail",
-    "1.61.1",
+    "1.65.0",
     __name__[0:-6],
-    "aws-pinpointemail@1.61.1.jsii.tgz",
+    "aws-pinpointemail@1.65.0.jsii.tgz",
 )
 
 __all__ = [
